@@ -210,6 +210,12 @@ function insertImg(src){
 
 	$('edit').contentWindow.document.body.innerHTML = body;
 }
+function insertEmoji(src){
+	var body = $('edit').contentWindow.document.body.innerHTML.toString();
+	body += '<img src="'+ src +'" class="emoji">';
+
+	$('edit').contentWindow.document.body.innerHTML = body;
+}
 
 function insertImgLink(href,src){
 	var body = $('edit').contentWindow.document.body.innerHTML.toString();
