@@ -13,6 +13,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/
  - 更新履歴：
+ -      [2007/06/08]    全テーブル名の取得関数追加
  -      [2007/03/11]    入力データのエスケープ処理指定を追加
  -      [2006/12/17]    作成
  - ======================================================================== */
@@ -37,13 +38,13 @@ class manip_pgsql
      * テーブル名
      * @var string
      */
-    var $tbl_name = "";
+    var $tbl_name = '';
 
     /**
-     * テーブル名
-     * @var string
+     * プライマリキー
+     * @var array
      */
-    var $primary_key = "";
+    var $primary = array();
 
     /**
      * コンストラクタ
@@ -59,6 +60,18 @@ class manip_pgsql
         $this->tbl_name = $tbl_name;
     }
 
+    /**
+     * テーブル名の設定
+     *
+     * @access public
+     * @param string $tbl_name
+     * @return void
+     */
+    function setTableName($tbl_name)
+    {
+        $this->tbl_name = $tbl_name;
+    }
+
     /**
      * プライマリキーの取得
      *
@@ -67,7 +80,34 @@ class manip_pgsql
      */
     function getPrimaryKey()
     {
-        return $this->primary_key;
+        return $this->primary['key'];
+    }
+
+    /**
+     * 全テーブル名の取得
+     *
+     * @access public
+     * @return array
+     */
+    function getTables()
+    {
+        $sql =
+            'SELECT '.
+                'tablename '.
+            'FROM '.
+                'pg_tables '.
+            'WHERE '.
+                "NOT tablename LIKE 'pg%'";
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
+
+        $list = array();
+        foreach ($result as $value){
+            $list[] = $value['tablename'];
+        }
+
+        return $list;
     }
 
     /**
@@ -79,7 +119,6 @@ class manip_pgsql
      */
     function parseColumns($skip=array())
     {
-        $result = null;
         $sql=
             'SELECT '.
                 'att.attname,'.
@@ -113,6 +152,7 @@ class manip_pgsql
             $parse = $this->parse_type($value['typname'],$key,$value['atttypmod']);
             $infos = array(
                 'type'=>    $parse['type'],
+                'pdo_type'=>$parse['pdo_type'],
                 'option'=>  $parse['option'],
                 'required'=>$this->parse_required($value['attnotnull']),
                 'effect'=>  array('RKT_validate', 'escape_character'),
@@ -120,7 +160,7 @@ class manip_pgsql
 
             /* プライマリキーは別扱い */
             if ($value['attnum'] == $value['indkey']){
-                $this->primary_key = array(
+                $this->primary = array(
                     'key'=>  $key,
                     'info'=> $infos
                 );
@@ -144,7 +184,8 @@ class manip_pgsql
      */
     function parse_type($subject,$field,$size)
     {
-        $type = 'number';
+        $type = 'string';
+        $pdo_type = PDO_PARAM_STR;
         $option = null;
         $size -= 4;
         if ($size <= 0){
@@ -159,6 +200,7 @@ class manip_pgsql
             );
         } else if (preg_match("/int/i",$subject)){
             $type = 'number';
+            $pdo_type = PDO_PARAM_INT;
         } else if (preg_match("/text/i",$subject)){
             $type = 'string';
             $option = array(
@@ -176,16 +218,19 @@ class manip_pgsql
             );
         } else if (preg_match("/float/i",$subject)){
             $type = 'number';
+            $pdo_type = PDO_PARAM_INT;
             $option = array(
                 'decimal'=>'.'
             );
         } else if (preg_match("/double/i",$subject)){
             $type = 'number';
+            $pdo_type = PDO_PARAM_INT;
             $option = array(
                 'decimal'=>'.'
             );
         } else if (preg_match("/bytea/i",$subject)){
             $type = 'string';
+            $pdo_type = PDO_PARAM_LOB;
             $option = array(
                 'max_length'=>$size
             );
@@ -220,7 +265,7 @@ class manip_pgsql
             );
         }
         
-        return array('type'=>$type, 'option'=>$option);
+        return array('type'=>$type, 'pdo_type'=>$pdo_type, 'option'=>$option);
     }
 
     /**
