@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/07/05] 絵文字コンバートで文字コードの変更はなし
  -      [2007/06/17] コミュニティ：トピック、イベント、記事、アンケート権限追加
  -      [2007/06/17] あしあと追加
  -      [2007/02/12] コミュニティメンバーステータスをビットフラグに変更
@@ -142,10 +143,11 @@ class WAP_community extends RKT_webapp
             }
         } // foreach ($_GET as $key=> $value)
 
-        $this->base['sid']  = session_id();
-        $this->base['url']  = BASE_URL;
-        $this->base['http'] = HTTP_ACTION;
-        $this->base['ssl']  = SSL_ACTION;
+        $this->base['sid']    = session_id();
+        $this->base['url']    = BASE_URL;
+        $this->base['http']   = HTTP_ACTION;
+        $this->base['ssl']    = SSL_ACTION;
+        $this->base['config'] = 'community.conf';
 
         $this->base['uri_separator']  = htmlspecialchars(WAP_URI_SEPARATOR);
     }
@@ -385,6 +387,24 @@ class WAP_community extends RKT_webapp
             $this->ins_accesslog = $this->objdb->exec($sql);
         }
     }
+
+    /**
+     * 絵文字コンバート
+     *
+     * @access public
+     * @return void
+     **/
+    function emojiConvert($string)
+    {
+        static $objemoji;
+        
+        if (empty($objemoji)) {        
+            $objemoji = new RKT_emoji();
+        }
+        $string = $objemoji->convert($string, 'Tag');
+
+        return $string;
+    }
 }
 // WAP_communityの終了
 ?>
