@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/07/05] 絵文字コンバートで文字コードの変更はなし
  -      [2006/09/20] $this->base['uri_separator']を追加
  -      [2006/07/10] 作成
  - ======================================================================== */
@@ -28,6 +29,7 @@
 require_once LIB_DIR.'rkt_db.php';
 require_once LIB_DIR.'rkt_validate.php';
 require_once LIB_DIR.'rkt_auth.php';
+require_once LIB_DIR.'rkt_emoji.php';
 require_once LIB_DIR.'rkt_webapp.php';
 
 /**
@@ -101,10 +103,11 @@ class WAP_private extends RKT_webapp
             }
         } // foreach ($_GET as $key=> $value)
         
-        $this->base['sid']  = session_id();
-        $this->base['url']  = BASE_URL;
-        $this->base['http'] = HTTP_ACTION;
-        $this->base['ssl']  = SSL_ACTION;
+        $this->base['sid']    = session_id();
+        $this->base['url']    = BASE_URL;
+        $this->base['http']   = HTTP_ACTION;
+        $this->base['ssl']    = SSL_ACTION;
+        $this->base['config'] = 'private.conf';
 
         $this->base['uri_separator']  = htmlspecialchars(WAP_URI_SEPARATOR);
     }
@@ -172,6 +175,24 @@ class WAP_private extends RKT_webapp
             $this->account['height'] = PHOTO_SMALL_SIZE;
         }
     }
+
+    /**
+     * 絵文字コンバート
+     *
+     * @access public
+     * @return void
+     **/
+    function emojiConvert($string)
+    {
+        static $objemoji;
+        
+        if (empty($objemoji)) {        
+            $objemoji = new RKT_emoji();
+        }
+        $string = $objemoji->convert($string, 'Tag');
+
+        return $string;
+    }
 }
 // WAP_privateの終了
 ?>
