@@ -95,7 +95,7 @@ class webapp extends WAP_private
         $result = $this->do_query();
         if ($result == RKT_MANIP_COMPLETE){
             $this->update_entry();
-            header('Location: '.HTTP_ACTION.'private/diary/comments/'.$this->sid.'/complete/'.WAP_URI_SEPARATOR.'ref_entry='.$this->ref_entry);
+            header('Location: '.HTTP_ACTION.'private/diary/comments/'.$this->sid.'/'.$this->ref_entry.'/complete/');
             exit();
         } elseif($result == RKT_MANIP_VALIDATED) {
             header('Location: '.HTTP_ACTION.'private/diary/comment/'.$this->sid.'/confirm/'.WAP_URI_SEPARATOR.'ref_entry='.$this->ref_entry);
@@ -254,6 +254,8 @@ class webapp extends WAP_private
         $this->objmnp->setValue('ref_entry', $this->ref_entry);
         $this->objmnp->setValue('flag', COMMENT_FLAG_READ);
 
+        $this->objmnp->setInputEffect('body', array('func'=>array('webapp', 'emojiConvert')));
+
         // 更新しない項目名
         $skip = array(
             'link',
