@@ -21,6 +21,8 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/07/07] SMTPの設定を追加
+ -      [2007/07/05] Smarty設定ディレクトリパスの変更
  -      [2007/06/17] アクセス権限定義を追加
  -      [2007/06/08] manip(ulation)用DBクラス保存ディレクトリパス定義を追加
  -      [2007/05/28] 管理者と初期ユーザーを統合
@@ -92,6 +94,15 @@ define('USE_SET_NAMES', '0');                                       // SET NAMES
 define('IMAGEMAGICK_PATH', '/usr/local/bin/');                      // ImageMagickのパス
 define('IMAGE_DRIVER', 'gd');                                       // 使用する画像加工ドライバ
 
+/* ---------------------------------------- */
+/* SMTPメール設定 */
+define('USED_SMTP', FALSE);                                         // SMTPの使用
+define('SMTP_HOST', 'mail.example.com');                            // SMTPホスト
+define('SMTP_PORT', 25);                                            // SMTPポート
+define('SMTP_AUTH', FALSE);                                         // SMTP認証
+define('SMTP_ACCOUNT', 'send@example.com');                         // SMTPアカウント
+define('SMTP_PASSWORD', 'passwd');                                  // SMTPパスワード
+
 /* ---------------------------------------- */
 /* POP3メール設定 */
 define('POP3_HOST', 'mail.example.com');                            // POP3ホスト
@@ -147,7 +158,7 @@ define('BLOB_DB_FILE', DB_DIR.'blob.db');                           // バイナ
 /* ---------------------------------------- */
 /* Smarty（テンプレートエンジン）の定義部分 */
 define('SMARTY_DIR' ,LIB_DIR.'Smarty'. DIRECTORY_SEPARATOR);            // Smartyライブラリパス
-define('SMARTY_CONFIG_DIR', SMARTY_DIR.'configs'.DIRECTORY_SEPARATOR);  // Smartyコンフィグパス
+define('SMARTY_CONFIG_DIR', WORK_DIR.'configs'.DIRECTORY_SEPARATOR);    // Smartyコンフィグパス
 /* ---------------------------------------- */
 
 /* ---------------------------------------- */
