@@ -495,6 +495,38 @@ class WAP_friend extends RKT_webapp
         }
         return $result['ref_friend'];
     }
+
+    /**
+     * 絵文字エディタ用の初期化設定
+     *
+     * @access public
+     * @return void
+     */
+    function setEmojiInit()
+    {
+        $this->addCss('yui_container.css');
+        $this->addJavas('YUI/yahoo-min.js');
+        $this->addJavas('YUI/event-min.js');
+        $this->addJavas('YUI/dom-min.js');
+        $this->addJavas('YUI/dragdrop-min.js');
+        $this->addJavas('YUI/container-min.js');
+
+        $this->base['javascript'] = empty($this->base['javascript'])?'':$this->base['javascript'];
+
+        $init = 
+            'YAHOO.namespace("emoji.container");'."\r\n".
+            "\r\n".
+            'function init() {'."\r\n".
+                'YAHOO.emoji.container.panel = new YAHOO.widget.Panel("emoji_table", { width:"240px", visible:false, constraintoviewport:true } );'."\r\n".
+                'YAHOO.emoji.container.panel.render();'."\r\n".
+                "\r\n".
+                'YAHOO.util.Event.addListener("show", "click", YAHOO.emoji.container.panel.show, YAHOO.emoji.container.panel, true);'."\r\n".
+                'YAHOO.util.Event.addListener("hide", "click", YAHOO.emoji.container.panel.hide, YAHOO.emoji.container.panel, true);'."\r\n".
+            '}'."\r\n".
+            "\r\n".
+            'YAHOO.util.Event.addListener(window, "load", init);';
+        $this->base['javascript'] .= $init;
+    }
 }
 // WAP_friendの終了
 ?>
