@@ -65,6 +65,12 @@ class webapp extends WAP_community
      */
     var $com_option = array();
 
+    /**
+     * 作成権限
+     * @var integer
+     */
+    var $permission = true;
+
     /**
      * 実行処理
      *
@@ -139,9 +145,13 @@ class webapp extends WAP_community
 
         $this->Assign('picture', $objpic->getImgInfos());
 
-        $this->set_crosseditor();
         $this->set_date();
         $this->set_option();
+
+        if ($this->permission){
+            $this->set_crosseditor();
+            $this->setEmojiInit();
+        }
     }
 
     /**
@@ -243,6 +253,10 @@ class webapp extends WAP_community
      */
     function format_comment($string)
     {
+        $pattern  = '<img src="'.preg_quote(BASE_URL.'resource/img/emoji/','/');
+        $pattern .= '(\d+).gif" class\="emoji"(\s\/)?>';
+        $string = preg_replace('/'.$pattern.'/i', '[m:\1]', $string);
+
         $string = preg_replace('/<p>/i', '', $string);
         $string = preg_replace('/<\/p>/i', '<br />', $string);
 
@@ -264,6 +278,7 @@ class webapp extends WAP_community
         if ($this->community['enquete_flag'] == PERMISSION_ADMIN){
             if (!$this->base['admin']){
                 $this->Assign('permission_denied', true);
+                $this->permission = false;
                 return false;
             }
         } // if ($this->community['enquete_flag'] == PERMISSION_ADMIN)
