@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/07/01] 絵文字エディタを追加
  -      [2007/06/16] 日記の公開レベルを追加
  -      [2007/02/13] フォーマットがWYSIWYGエディタならジャンプ
  -      [2007/02/02] カテゴリ選択更新時エラーを修正
@@ -93,7 +94,6 @@ class webapp extends WAP_private
         RKT_auth::Authenticate(array(WAP_ACC_ADMIN,WAP_ACC_MEMBER));
 
         $this->setTemplateFile('private/diary/post.tpl');
-
         /* URL引数の取得 */
         $this->setSafety('id');
         $this->setSafety('plain');
@@ -158,6 +158,8 @@ class webapp extends WAP_private
             VISIBILITY_HIDDEN=>    VISIBILITY_LABEL_HIDDEN,
         );
         $this->Assign('visibilitys', $visibilitys);
+
+        $this->setEmojiInit();
     }
 
     /**
