@@ -163,6 +163,8 @@ class webapp extends WAP_private
             VISIBILITY_HIDDEN=>    VISIBILITY_LABEL_HIDDEN,
         );
         $this->Assign('visibilitys', $visibilitys);
+
+        $this->setEmojiInit();
     }
 
     /**
@@ -252,6 +254,10 @@ class webapp extends WAP_private
      */
     function format_body($string)
     {
+        $pattern  = '<img src="'.preg_quote(BASE_URL.'resource/img/emoji/','/');
+        $pattern .= '(\d+).gif" class\="emoji"(\s\/)?>';
+        $string = preg_replace('/'.$pattern.'/i', '[m:\1]', $string);
+
         $string = preg_replace('/<p>/i', '', $string);
         $string = preg_replace('/<\/p>/i', '<br />', $string);
 
