@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/06/25] PDO::と定数を宣言するエラーを修正（byトシヒコさま）
  -      [2007/02/12] コミュニティメンバーステータスをビットフラグに変更
  -      [2006/08/29] 表示整形の不具合修正
  -      [2006/07/29] 作成
@@ -539,7 +540,7 @@ class webapp extends WAP_public
                 sql_query::bitFlag('visibility & '.VISIBILITY_PUBLIC);
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
-        $result = $stmt->fetch(PDO::FETCH_ASSOC);
+        $result = $stmt->fetch(PDO_FETCH_ASSOC);
         $stmt->closeCursor();
         if (empty($result)){
             return false;
