@@ -188,13 +188,11 @@ class webapp extends WAP_public
                 DB_PREFIX.'dia_diary ('.
                     'modify,'.
                     'ref_account,'.
-                    'visibility,'.
                     'url,'.
                     'rss '.
                 ') VALUES ('.
                     "'".date('Y-m-d H:i:s')."',".
                     $this->id.','.
-                    VISIBILITY_PROTECTED.','.
                     "'',".
                     "''".
                 ')';
